@@ -1,11 +1,6 @@
-use std::env;
-use std::ptr::null_mut;
-use winapi::um::winnt::PWSTR;
 use nxui::directory_chooser::DirectoryChooser;
 use nxui::file_chooser::OpenFileDialog;
 use nxui::natives_and_messaging::*;
-use nxui::util::pwstr_to_string;
-use nxui::window::Frame;
 
 fn main() {
     nxui::initialize();
