@@ -3,7 +3,7 @@
 //! What starts with BUTTONSTYLE is a constant for changing the buttons in the dialog.
 
 
-pub type FILE_CHOOSER_STYLE = i32;
+pub type FileChooserStyle = i32;
 
 // Dialog Styles
 
@@ -269,11 +269,11 @@ pub const AWS_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Util
 #[cfg(windows)]
 pub const FC_NONE:winapi::shared::minwindef::DWORD = 0;
 #[cfg(unix)]
-pub const FC_NONE:FILE_CHOOSER_STYLE = 0;
+pub const FC_NONE: FileChooserStyle = 0;
 #[cfg(windows)]
 pub const FC_DISABLE_READ_ONLY:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_HIDEREADONLY;
 #[cfg(unix)]
-pub const FC_DISABLE_READ_ONLY:FILE_CHOOSER_STYLE = 0;
+pub const FC_DISABLE_READ_ONLY: FileChooserStyle = 0;
 /// Windows Only
 #[cfg(windows)]
 pub const FC_NEW_EXPLORER:winapi::shared::minwindef::DWORD = winapi::um::commdlg::OFN_EXPLORER;
